@@ -1,6 +1,8 @@
 
 /******************************************************************************
 **
+**  Copyright (C) 2005 Brian Wotring.
+**
 **  This program is free software; you can redistribute it and/or
 **  modify it, however, you cannot sell it.
 **
@@ -9,8 +11,10 @@
 **  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 **
 **  You should have received a copy of the license attached to the
-**  use of this software.  If not, visit www.shmoo.com/osiris for
-**  details.
+**  use of this software.  If not, view a current copy of the license
+**  file here:
+**
+**      http://www.hostintegrity.com/osiris/LICENSE
 **
 ******************************************************************************/
 
@@ -102,7 +106,13 @@ osi_bool md_filter_pattern( OSI_DB *filter_db, const char *pattern )
 
         OSI_DEBUG( __POS__, "applying filter: exclude=(%s)", filter.exclude);
 
-        /* host doesn't match. */
+        /* if disabled, go to the next filter.  disabled filters */
+        /* are noted by the first character being a "#".         */
+
+        if ( filter.exclude[0] == FILTER_DISABLED_MARK )
+        {
+            goto next_filter;
+        }
 
         if( strlen(filter.exclude) &&
             name_regex( pattern, filter.exclude) == FALSE )
