@@ -1,6 +1,8 @@
 
 /******************************************************************************
 **
+**  Copyright (C) 2005 Brian Wotring.
+**
 **  This program is free software; you can redistribute it and/or
 **  modify it, however, you cannot sell it.
 **
@@ -9,8 +11,10 @@
 **  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 **
 **  You should have received a copy of the license attached to the
-**  use of this software.  If not, visit www.shmoo.com/osiris for
-**  details.
+**  use of this software.  If not, view a current copy of the license
+**  file here:
+**
+**      http://www.hostintegrity.com/osiris/LICENSE
 **
 ******************************************************************************/
 
@@ -112,11 +116,13 @@ SSL *control_connection_ssl   = NULL;
 #ifndef WIN32
 pid_t pid;
 pid_t scheduler_pid;
+pid_t log_pid;
 #endif
 
 int user_pipe[2];
 int schedule_pipe[2];
 int restart_pipe[2];
+int log_pipe[2] = { -1,-1 };
 
 char config_file_path[MAX_PATH_LENGTH]     = DEFAULT_CONFIG_PATH;
 char root_path[MAX_PATH_LENGTH]            = OSIRISMD_ROOT_DIR;
@@ -168,6 +174,7 @@ void fork_daemon_process();
 void start_scheduler();
 
 void start_servers();
+void start_log_application();
 void shutdown_servers();
 void shutdown_scheduler();
 
